import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:provider/provider.dart';

import '/flutter_flow/custom_functions.dart' as functions;
import '/flutter_flow/flutter_flow_theme.dart';
import '/flutter_flow/flutter_flow_util.dart';
import 'local_profile_component_model.dart';

export 'local_profile_component_model.dart';

////

class LocalProfileComponentWidget extends StatefulWidget {
  LocalProfileComponentWidget({Key? key, required this.showBottomSheet})
      : super(key: key);

  VoidCallback showBottomSheet;

  @override
  State<LocalProfileComponentWidget> createState() =>
      _LocalProfileComponentWidgetState();
}

class _LocalProfileComponentWidgetState
    extends State<LocalProfileComponentWidget> {
  late LocalProfileComponentModel _model;

  @override
  void setState(VoidCallback callback) {
    super.setState(callback);
    _model.onUpdate();
  }

  @override
  void initState() {
    super.initState();
    _model = createModel(context, () => LocalProfileComponentModel());
  }

  @override
  void dispose() {
    _model.maybeDispose();

    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    context.watch<AppState>();

    return Container(
      decoration: const BoxDecoration(),
      child: Align(
        alignment: const AlignmentDirectional(0.0, -1.0),
        child: Material(
          color: Colors.transparent,
          elevation: 0.0,
          child: Container(
            width: double.infinity,
            height: 119.0,
            decoration: BoxDecoration(
              color: FlutterFlowTheme.of(context).primary,
              border: Border.all(
                color: FlutterFlowTheme.of(context).primary,
              ),
            ),
            child: Row(
              mainAxisSize: MainAxisSize.max,
              children: [
                Align(
                  alignment: const AlignmentDirectional(-1.0, 0.0),
                  child: Padding(
                    padding: const EdgeInsets.all(2.0),
                    child: InkWell(
                        splashColor: Colors.transparent,
                        focusColor: Colors.transparent,
                        hoverColor: Colors.transparent,
                        highlightColor: Colors.transparent,
                        onTap: () async {
                          widget.showBottomSheet();
                        },
                        child: ClipRRect(
                          borderRadius: BorderRadius.circular(200.0),
                          child: CachedNetworkImage(
                            imageBuilder: (context, imageProvider) => Container(
                              decoration: BoxDecoration(
                                image: DecorationImage(
                                  image: imageProvider,
                                  fit: BoxFit.cover,
                                ),
                              ),
                            ),
                            imageUrl: valueOrDefault(
                                'https://freaccess.com.br/freaccess/Images/Clients/${AppState().cliUUID}.png',
                                'assets/images/home.png'),
                            width: 80.0,
                            height: 80.0,
                            fit: BoxFit.cover,
                            alignment: const Alignment(0.0, 0.0),
                            placeholder: (context, url) =>
                                Image.asset('assets/images/home.png'),
                            errorListener: (_) =>
                                Image.asset('assets/images/home.png'),
                            errorWidget: (_, __, ___) =>
                                Image.asset('assets/images/home.png'),
                          ),
                        )),
                  ),
                ),
                Text(
                  valueOrDefault<String>(
                      functions.convertToUppercase(AppState().local),
                      FFLocalizations.of(context).getVariableText(
                        ptText: 'SEM LOCAL VINCULADO',
                        enText: 'NO LINKED LOCAL',
                      )),
                  style: FlutterFlowTheme.of(context).labelMedium.override(
                        fontFamily: 'Nunito',
                        color: FlutterFlowTheme.of(context).info,
                        fontSize: 14.0,
                        letterSpacing: 0.0,
                        fontWeight: FontWeight.w500,
                        useGoogleFonts:
                            GoogleFonts.asMap().containsKey('Nunito'),
                      ),
                ),
              ]
                  .divide(const SizedBox(width: 20.0))
                  .addToStart(const SizedBox(width: 20.0))
                  .addToEnd(const SizedBox(width: 20.0)),
            ),
          ),
        ),
      ),
    );
  }
}
