import 'package:flutter/material.dart';
import 'package:hub/components/organism_components/menu_staggered_view_component/menu_staggered_view_component_model.dart';
import 'package:hub/flutter_flow/nav/nav.dart';
import 'package:hub/shared/extensions/dialog_extensions.dart';

import '/components/molecular_components/option_selection_modal/option_selection_modal_widget.dart';
import '/components/organism_components/menu_list_view_component/menu_list_view_component_widget.dart';
import '/flutter_flow/flutter_flow_util.dart';
import 'menu_component_widget.dart' show MenuComponentWidget;

class MenuComponentModel extends FlutterFlowModel<MenuComponentWidget> {
  ///  Local state fields for this component.

  bool isGrid = false;

  ///  State fields for stateful widgets in this component.

  // Model for menuListViewComponent.
  late MenuListViewComponentModel menuListViewComponentModel;

  // Model for menuStaggeredViewComponent.
  late MenuStaggeredViewComponentModel menuStaggeredViewComponentModel;

  @override
  void initState(BuildContext context) {
    menuListViewComponentModel =
        createModel(context, () => MenuListViewComponentModel());
    menuStaggeredViewComponentModel =
        createModel(context, () => MenuStaggeredViewComponentModel());
  }

  @override
  void dispose() {
    menuListViewComponentModel.dispose();
    menuStaggeredViewComponentModel.dispose();
  }

  /// Action blocks.
  Future changeMenuStyle(BuildContext context) async {
    isGrid = !isGrid;
  }

  Future accessQRCodeOptAction(BuildContext context) async {
    context.push(
      '/qrCodePage',
      extra: <String, dynamic>{
        kTransitionInfoKey: const TransitionInfo(
          hasTransition: true,
          transitionType: PageTransitionType.scale,
          alignment: Alignment.bottomCenter,
        ),
      },
    );
  }

  Future scheduleCompleteVisitAction(BuildContext context) async {
    context.push(
      '/scheduleCompleteVisitPage',
      extra: <String, dynamic>{
        kTransitionInfoKey: const TransitionInfo(
          hasTransition: true,
          transitionType: PageTransitionType.scale,
          alignment: Alignment.bottomCenter,
        ),
      },
    );
  }

  Future deliverySchedule(BuildContext context) async {
    final isProvisional = AppState().provisional;
    if (isProvisional == true) {
      context.push(
        '/deliverySchedule',
        extra: <String, dynamic>{
          kTransitionInfoKey: const TransitionInfo(
            hasTransition: true,
            transitionType: PageTransitionType.scale,
            alignment: Alignment.bottomCenter,
          ),
        },
      );
    } else {
      DialogUnavailable.unavailableFeature(context);
    }
  }

  Future provisionalSchedule(BuildContext context) async {
    final isProvisional = AppState().provisional;
    if (isProvisional == true) {
      context.push(
        '/provisionalSchedule',
        extra: <String, dynamic>{
          kTransitionInfoKey: const TransitionInfo(
            hasTransition: true,
            transitionType: PageTransitionType.scale,
            alignment: Alignment.bottomCenter,
          ),
        },
      );
    } else {
      DialogUnavailable.unavailableFeature(context);
    }
  }

  Future fastPassAction(BuildContext context) async {
    final isWpp = AppState().whatsapp;
    if (isWpp) {
      context.push(
        '/fastPassPage',
        extra: <String, dynamic>{
          kTransitionInfoKey: const TransitionInfo(
            hasTransition: true,
            transitionType: PageTransitionType.scale,
            alignment: Alignment.bottomCenter,
          ),
        },
      );
    } else {
      DialogUnavailable.unavailableFeature(context);
    }
  }

  Future scheduleVisitOptAction(BuildContext context) async {
    final routesListStr = <String>[
      'scheduleProvisionalVisitPage',
      'fastPassPage',
      'scheduleCompleteVisitPage',
    ];
    final iconsListIcon = <IconData>[
      Icons.date_range_rounded,
      Icons.date_range_rounded,
      Icons.date_range_rounded,
    ];
    final nameListStr = <String>[
      FFLocalizations.of(context).getVariableText(
        ptText: 'Visita\nProvisória',
        enText: 'Provisional\nSchedule',
      ),
      FFLocalizations.of(context).getVariableText(
        ptText: 'Visita\nRápida',
        enText: 'Fast\nSchedule',
      ),
      FFLocalizations.of(context).getVariableText(
        ptText: 'Visita\nCompleta',
        enText: 'Complete\nSchedule',
      ),
    ];

    await showAdaptiveDialog(
      context: context,
      builder: (context) {
        return Padding(
          padding: MediaQuery.viewInsetsOf(context),
          child: OptionSelectionModalWidget(
            routesListStr: routesListStr,
            iconsListIcon: iconsListIcon,
            nameListStr: nameListStr,
          ),
        );
      },
    );
  }

  Future registerVisitorOptAction(BuildContext context) async {
    context.push(
      '/registerVisitorPage',
      extra: <String, dynamic>{
        kTransitionInfoKey: const TransitionInfo(
          hasTransition: true,
          transitionType: PageTransitionType.scale,
          alignment: Alignment.bottomCenter,
        ),
      },
    );
  }

  Future peopleOnThePropertyAction(BuildContext context) async {
    context.push(
      '/peopleOnThePropertyPage',
      extra: <String, dynamic>{
        kTransitionInfoKey: const TransitionInfo(
          hasTransition: true,
          transitionType: PageTransitionType.fade,
        ),
      },
    );
  }

  Future<void> signOut(BuildContext context) async {
    showAlertDialog(
        context,
        'Logout',
        FFLocalizations.of(context).getVariableText(
          enText: 'Are you sure you want to logout?',
          ptText: 'Tem certeza',
        ), () async {
      AppState().deleteAll();

      context.go(
        '/welcomePage',
        extra: <String, dynamic>{
          kTransitionInfoKey: const TransitionInfo(
            hasTransition: true,
            transitionType: PageTransitionType.scale,
            alignment: Alignment.bottomCenter,
          ),
        },
      );
    });
  }

  Future preferencesSettings(BuildContext context) async {
    context.push(
      '/preferencesSettings',
      extra: <String, dynamic>{
        kTransitionInfoKey: const TransitionInfo(
          hasTransition: true,
          transitionType: PageTransitionType.scale,
          alignment: Alignment.bottomCenter,
        ),
      },
    );
  }

  Future packageOrder(BuildContext context) async {
    final isWpp = AppState().whatsapp;

    if (isWpp) {
      context.push(
        '/packageOrder',
        extra: <String, dynamic>{
          kTransitionInfoKey: const TransitionInfo(
            hasTransition: true,
            transitionType: PageTransitionType.scale,
            alignment: Alignment.bottomCenter,
          ),
        },
      );
    } else {
      DialogUnavailable.unavailableFeature(context);
    }
  }

  Future reservation(BuildContext context) async {
    final isWpp = AppState().whatsapp;
    if (isWpp) {
      context.push(
        '/reservation',
        extra: <String, dynamic>{
          kTransitionInfoKey: const TransitionInfo(
            hasTransition: true,
            transitionType: PageTransitionType.scale,
            alignment: Alignment.bottomCenter,
          ),
        },
      );
    } else {
      DialogUnavailable.unavailableFeature(context);
    }
  }

  Future consultHistoriesAction(BuildContext context) async {
    await showAdaptiveDialog(
      // isScrollControlled: true,
      // backgroundColor: Colors.transparent,
      // enableDrag: false,
      context: context,
      builder: (context) {
        return Padding(
          padding: MediaQuery.viewInsetsOf(context),
          child: OptionSelectionModalWidget(
            routesListStr: <String>[
              'liberationHistory',
              'acessHistoryPage',
              'scheduleCompleteVisitPage',
              'messageHistoryPage'
            ],
            iconsListIcon: <IconData>[
              Icons.history_rounded,
              Icons.history_rounded,
              Icons.history_rounded,
              Icons.history_rounded,
            ],
            nameListStr: <String>[
              FFLocalizations.of(context).getVariableText(
                ptText: 'Histórico\nde Liberação',
                enText: 'Liberation\nHistory',
              ),
              FFLocalizations.of(context).getVariableText(
                ptText: 'Histórico\nde Acesso',
                enText: 'Access\nHistory',
              ),
              FFLocalizations.of(context).getVariableText(
                ptText: 'Histórico\nde Visita',
                enText: 'Visit\nHistory',
              ),
              FFLocalizations.of(context).getVariableText(
                ptText: 'Histórico\nde Mensagens',
                enText: 'Message\nHistory',
              ),
            ],
          ),
        );
      },
    );
  }

  Future liberationHistoryAction(BuildContext context) async {
    context.push(
      '/liberationHistory',
      extra: <String, dynamic>{
        kTransitionInfoKey: const TransitionInfo(
          hasTransition: true,
          transitionType: PageTransitionType.scale,
          alignment: Alignment.bottomCenter,
        ),
      },
    );
  }

  Future accessHistoryAction(BuildContext context) async {
    context.push(
      '/acessHistoryPage',
      extra: <String, dynamic>{
        kTransitionInfoKey: const TransitionInfo(
          hasTransition: true,
          transitionType: PageTransitionType.scale,
          alignment: Alignment.bottomCenter,
        ),
      },
    );
  }

  Future visitHistoryAction(BuildContext context) async {
    context.push(
      '/scheduleCompleteVisitPage',
      extra: <String, dynamic>{
        kTransitionInfoKey: const TransitionInfo(
          hasTransition: true,
          transitionType: PageTransitionType.scale,
          alignment: Alignment.bottomCenter,
        ),
      },
    );
  }

  Future messageHistoryAction(BuildContext context) async {
    context.push(
      '/messageHistoryPage',
      extra: <String, dynamic>{
        kTransitionInfoKey: const TransitionInfo(
          hasTransition: true,
          transitionType: PageTransitionType.scale,
          alignment: Alignment.bottomCenter,
        ),
      },
    );
  }
}
